@@ -20,7 +20,7 @@ import httpx
 import json
 import logging
 import os
-from typing import List, Optional, Dict, TYPE_CHECKING
+from typing import List, Optional, Dict, Any, TYPE_CHECKING
 
 from .base import EnvironmentBase, SyncWrapper
 from .models import (
@@ -50,7 +50,7 @@ from .instance.client import ValidatorType
 from .resources.base import Resource
 from .resources.sqlite import SQLiteResource
 from .resources.browser import BrowserResource
-from .resources.mcp import MCPResource
+from .resources.mcp import SyncMCPResource
 
 logger = logging.getLogger(__name__)
 
@@ -105,9 +105,9 @@ class SyncEnv(EnvironmentBase):
         return self.instance.browser(name)
 
     @property
-    def mcp(self) -> MCPResource:
+    def mcp(self) -> SyncMCPResource:
         mcp_url = f"{self.urls.root}mcp"
-        return MCPResource(url=mcp_url, env_key=self.env_key)
+        return SyncMCPResource(url=mcp_url, env_key=self.env_key)
 
     def state(self, uri: str) -> Resource:
         return self.instance.state(uri)
@@ -196,7 +196,7 @@ class Fleet:
         response = self.client.request("GET", f"/v1/env/{env_key}")
         return EnvironmentModel(**response.json())
 
-    def make(self, env_key: str, region: Optional[str] = None) -> SyncEnv:
+    def make(self, env_key: str, region: Optional[str] = None, env_variables: Optional[Dict[str, Any]] = None) -> SyncEnv:
         if ":" in env_key:
             env_key_part, version = env_key.split(":", 1)
             if (
@@ -210,7 +210,7 @@ class Fleet:
             version = None
 
         request = InstanceRequest(
-            env_key=env_key_part, version=version, region=region, created_from="sdk"
+            env_key=env_key_part, version=version, region=region, env_variables=env_variables, created_from="sdk"
         )
         region_base_url = REGION_BASE_URL.get(region)
         response = self.client.request(
@@ -254,7 +254,9 @@ class Fleet:
     def execute_verifier_remote(
         self, bundle_data: bytes, args: tuple, kwargs: dict, timeout: Optional[int] = 30
     ) -> VerifiersExecuteResponse:
-        return _execute_verifier_remote(self.client, bundle_data, args, kwargs, timeout)
+        return _execute_verifier_remote(
+            self.client, bundle_data, args, kwargs, timeout
+        )
 
     def delete(self, instance_id: str) -> InstanceResponse:
         return _delete_instance(self.client, instance_id)
@@ -265,7 +267,9 @@ class Fleet:
 
         return self.load_task_array_from_string(tasks_data)
 
-    def load_task_array_from_string(self, serialized_tasks: List[Dict]) -> List[Task]:
+    def load_task_array_from_string(
+        self, serialized_tasks: List[Dict]
+    ) -> List[Task]:
         tasks = []
 
         json_tasks = json.loads(serialized_tasks)
@@ -303,11 +307,20 @@ class Fleet:
         )
         return task
 
-    def load_tasks(self, env_key: Optional[str] = None) -> List[Task]:
-        """Load tasks for the authenticated team, optionally filtered by environment.
+    def load_tasks(
+        self, 
+        env_key: Optional[str] = None,
+        keys: Optional[List[str]] = None,
+        version: Optional[str] = None,
+        team_id: Optional[str] = None
+    ) -> List[Task]:
+        """Load tasks for the authenticated team, with optional filtering.
 
         Args:
             env_key: Optional environment key to filter tasks by
+            keys: Optional list of task keys to filter by
+            version: Optional version to filter tasks by (client-side filter)
+            team_id: Optional team_id to filter by (admin only)
 
         Returns:
             List[Task] containing Task objects
@@ -315,6 +328,10 @@ class Fleet:
         params = {}
         if env_key is not None:
             params["env_key"] = env_key
+        if keys is not None:
+            params["task_keys"] = keys
+        if team_id is not None:
+            params["team_id"] = team_id
 
         response = self.client.request("GET", "/v1/tasks", params=params)
         task_list_response = TaskListResponse(**response.json())
@@ -375,6 +392,10 @@ class Fleet:
             )
             tasks.append(task)
 
+        # Apply client-side filtering for version if specified
+        if version is not None:
+            tasks = [task for task in tasks if task.version == version]
+
         return tasks
 
     def export_tasks(
@@ -464,7 +485,7 @@ class Fleet:
     def _create_verifier_from_data(
         self, verifier_id: str, verifier_key: str, verifier_code: str, verifier_sha: str
     ) -> "SyncVerifierFunction":
-        """Create a SyncVerifierFunction from verifier data.
+        """Create an AsyncVerifierFunction from verifier data.
 
         Args:
             verifier_id: The verifier ID
@@ -473,10 +494,10 @@ class Fleet:
             verifier_sha: The verifier SHA256
 
         Returns:
-            SyncVerifierFunction created from the verifier code
+            AsyncVerifierFunction created from the verifier code
         """
         from .tasks import verifier_from_string
-        from .verifiers.verifier import SyncVerifierFunction
+        from .verifiers import SyncVerifierFunction
         
         # Use verifier_from_string to create the verifier
         verifier_func = verifier_from_string(
@@ -486,12 +507,6 @@ class Fleet:
             sha256=verifier_sha,
         )
         
-        # Ensure we return a SyncVerifierFunction
-        if not isinstance(verifier_func, SyncVerifierFunction):
-            raise TypeError(
-                f"Expected SyncVerifierFunction but got {type(verifier_func).__name__}"
-            )
-        
         # Store the original verifier code for reference
         verifier_func._verifier_code = verifier_code
 
